;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "fpga" "20251002.1238"
  "FPGA & ASIC Utils."
  '((emacs "29.1"))
  :url "https://github.com/gmlarumbe/fpga"
  :commit "8e5f44d73d9bec693b9882113fa34827a5b4c2b1"
  :revdesc "8e5f44d73d9b"
  :keywords '("tools")
  :authors '(("Gonzalo Larumbe" . "gonzalomlarumbe@gmail.com"))
  :maintainers '(("Gonzalo Larumbe" . "gonzalomlarumbe@gmail.com")))
